//  
//   Rebex Sample Code License
// 
//   Copyright 2024, REBEX CR s.r.o.
//   All rights reserved.
//   https://www.rebex.net/
// 
//   Permission to use, copy, modify, and/or distribute this software for any
//   purpose with or without fee is hereby granted.
// 
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//   OTHER DEALINGS IN THE SOFTWARE.
// 

using System;
using System.Collections.Generic;
using System.Text;
using Rebex.IO.Compression;

namespace Rebex.Samples
{
    /// <summary>
    /// Command line arguments parser and storage.
    /// </summary>
    public class Arguments
    {
        /// <summary>
        /// Parses the command line and creates the instance of Arguments class
        /// </summary>
        /// <param name="args">Command line arguments.</param>
        public Arguments(string[] args)
        {
            if (args.Length == 0)
                throw new SampleException("Archive name is missing.");

            if (args.Length > 2)
                throw new SampleException("Too many arguments.");

            _zipArchivePath = args[0];

            if (args.Length == 2)
                _sourcePath = args[1];
        }

        /// <summary>
        /// Path to the ZIP archive on the disk.
        /// </summary>
        public string ZipArchivePath { get { return _zipArchivePath; } }
        private string _zipArchivePath;

        /// <summary>
        /// Specifies which files will be added. Supported wildcards: '*' and '?'.
        /// </summary>
        /// <example>"C:\data", "C:\file.txt", "C:\*.txt", "data", "file.txt", "*.txt", "*", etc.</example>
        public string SourcePath { get { return _sourcePath; } }
        private string _sourcePath = "*";

    }
}
